@@ -74,11 +74,11 @@ setMethod("rowSums", signature(x = "ratingMatrix"),
 ## we need to ignore 0s
 setMethod("colMeans", signature(x = "ratingMatrix"),
   function(x, na.rm = FALSE, dims = 1, ...)
-    colSums(x, dims, na.rm, ...) / colCounts(x, na.rm = na.rm, dims = dims, ...))
+    colSums(x, na.rm = na.rm, dims = dims, ...) / colCounts(x, na.rm = na.rm, dims = dims, ...))
 
 setMethod("rowMeans", signature(x = "ratingMatrix"),
   function(x, na.rm = FALSE, dims = 1, ...)
-    rowSums(x, dims, na.rm, ...) / rowCounts(x, na.rm = na.rm, dims = dims, ...))
+    rowSums(x, na.rm = na.rm, dims = dims, ...) / rowCounts(x, na.rm = na.rm, dims = dims, ...))
 
 ### Note: use x and not x@data here since binaryRatingMatrix uses itemsets
 ### (pkg arules) which are stored in transposed form (see binaryRatingMatrix.R)!
